summaryrefslogtreecommitdiff
path: root/hv.c
diff options
context:
space:
mode:
authorYves Orton <demerphq@gmail.com>2017-07-01 16:32:28 +0200
committerYves Orton <demerphq@gmail.com>2017-07-01 16:38:14 +0200
commitb6bb1ecbab2ac366ccb94da3406d2edf38553b42 (patch)
treec7fadf83f47e30a3c43ad8ae70d15508a0a9fed2 /hv.c
parent2176e0e925bd2df99ec4eb1ef956d38d9ecb8a90 (diff)
downloadperl-b6bb1ecbab2ac366ccb94da3406d2edf38553b42.tar.gz
hv.c: rename static function S_hfreeentries() to S_hv_free_entries()
hfreeentries() reads very poorly - hv_free_entries() makes more sense too.
Diffstat (limited to 'hv.c')
-rw-r--r--hv.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/hv.c b/hv.c
index 502c593de0..61f1f8f551 100644
--- a/hv.c
+++ b/hv.c
@@ -1754,7 +1754,7 @@ Perl_hv_clear(pTHX_ HV *hv)
}
}
else {
- hfreeentries(hv);
+ hv_free_entries(hv);
HvPLACEHOLDERS_set(hv, 0);
if (SvRMAGICAL(hv))
@@ -1851,7 +1851,7 @@ S_clear_placeholders(pTHX_ HV *hv, U32 items)
}
STATIC void
-S_hfreeentries(pTHX_ HV *hv)
+S_hv_free_entries(pTHX_ HV *hv)
{
STRLEN index = 0;
XPVHV * const xhv = (XPVHV*)SvANY(hv);
@@ -1866,7 +1866,7 @@ S_hfreeentries(pTHX_ HV *hv)
/* hfree_next_entry()
* For use only by S_hfreeentries() and sv_clear().
* Delete the next available HE from hv and return the associated SV.
* Returns null on empty hash. Nevertheless null is not a reliable
* indicator that the hash is empty, as the deleted entry may have a
@@ -1963,7 +1963,7 @@ Perl_hv_undef_flags(pTHX_ HV *hv, U32 flags)
DEBUG_A(Perl_hv_assert(aTHX_ hv));
xhv = (XPVHV*)SvANY(hv);
/* The name must be deleted before the call to hfreeentries so that
CVs are anonymised properly. But the effective name must be pre-
served until after that call (and only deleted afterwards if the
call originated from sv_clear). For stashes with one name that is
@@ -1971,7 +1971,7 @@ Perl_hv_undef_flags(pTHX_ HV *hv, U32 flags)
allocate an array for storing the effective name. We can skip that
during global destruction, as it does not matter where the CVs point
if they will be freed anyway. */
/* note that the code following prior to hfreeentries is duplicated
* in sv_clear(), and changes here should be done there too */
if (PL_phase != PERL_PHASE_DESTRUCT && HvNAME(hv)) {
if (PL_stashcache) {
@@ -1987,7 +1987,7 @@ Perl_hv_undef_flags(pTHX_ HV *hv, U32 flags)
PL_tmps_stack[++PL_tmps_ix] = SvREFCNT_inc_simple_NN(hv);
orig_ix = PL_tmps_ix;
}
- hfreeentries(hv);
+ hv_free_entries(hv);
if (SvOOK(hv)) {
struct mro_meta *meta;
const char *name;
@@ -1866,7 +1866,7 @@ S_hfreeentries(pTHX_ HV *hv)
/* hfree_next_entry()
- * For use only by S_hfreeentries() and sv_clear().
+ * For use only by S_hv_free_entries() and sv_clear().
* Delete the next available HE from hv and return the associated SV.
* Returns null on empty hash. Nevertheless null is not a reliable
@@ -1963,7 +1963,7 @@ Perl_hv_undef_flags(pTHX_ HV *hv, U32 flags)
DEBUG_A(Perl_hv_assert(aTHX_ hv));
xhv = (XPVHV*)SvANY(hv);
- /* The name must be deleted before the call to hfreeentries so that
+ /* The name must be deleted before the call to hv_free_entries so that
CVs are anonymised properly. But the effective name must be pre-
served until after that call (and only deleted afterwards if the
@@ -1971,7 +1971,7 @@ Perl_hv_undef_flags(pTHX_ HV *hv, U32 flags)
during global destruction, as it does not matter where the CVs point
if they will be freed anyway. */
- /* note that the code following prior to hfreeentries is duplicated
+ /* note that the code following prior to hv_free_entries is duplicated
* in sv_clear(), and changes here should be done there too */
if (PL_phase != PERL_PHASE_DESTRUCT && HvNAME(hv)) {